@@ -12,6 +12,14 @@ class AutoID(object):
     """Mixin adding a primary key integer column named 'id'."""
     id = db.Column(db.Integer, primary_key=True)
 
+    def _json(self, extended=False):
+        try:
+            parent = super(AutoName, self)._json(extended)
+        except AttributeError:
+            parent = {}
+        parent[u'id'] = self.id
+        return parent
+
 
 def _utcnow(arg):
     return dt.datetime.now(utc)
